self.__BUILD_MANIFEST={__rewrites:{beforeFiles:[],afterFiles:[],fallback:[]},"/":["static/chunks/e82996df-3710848f24a407443b07.js","static/chunks/29107295-2648cb5e919f7c78c7cc.js","static/chunks/249-cbf785bb47342695e736.js","static/chunks/pages/index-9eece7b31d33be3ab162.js"],"/_error":["static/chunks/pages/_error-b30902e13465df7c5366.js"],sortedPages:["/","/_app","/_error"]},self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB();